// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef GRANTLEETHEME_VERSION_H
#define GRANTLEETHEME_VERSION_H

#define GRANTLEETHEME_VERSION_STRING "6.2.3"
#define GRANTLEETHEME_VERSION_MAJOR 6
#define GRANTLEETHEME_VERSION_MINOR 2
#define GRANTLEETHEME_VERSION_PATCH 3
#define GRANTLEETHEME_VERSION ((6<<16)|(2<<8)|(3))

#endif
